### Links

-  Documentation: [palewi.re/docs/django-postgres-copy](https://django-postgres-copy.readthedocs.io/en/latest/)
-  Issues: [github.com/california-civic-data-coalition/django-postgres-copy/issues](https://github.com/california-civic-data-coalition/django-postgres-copy/issues)
-  Packaging: [pypi.python.org/pypi/django-postgres-copy](https://pypi.python.org/pypi/django-postgres-copy)
-  Testing: [github.com/california-civic-data-coalition/django-postgres-copy/actions](https://github.com/california-civic-data-coalition/django-postgres-copy/actions/workflows/test.yaml)
